@@ -33,7 +33,7 @@ _OCTET_RE = rb"(?:0x0*[a-f0-9]{1,2}|0*\d{1,3})"
 DOMAIN_RE = rb"(?i)(?<![-$\w.\\])(?:[a-z0-9-]+\.)+(?:xn--[a-z0-9]{4,18}|[a-z]{2,12})(?![a-z1-9.(=_@-])"
 EMAIL_RE = rb"(?i)\b[a-z0-9._%+-]{3,}@(" + DOMAIN_RE[4:] + rb")\b"
 
-IP_RE = rb"(?i)(?<![\w.-])(?:" + _OCTET_RE + rb"[.]){3}" + _OCTET_RE + rb"(?![\w.-])"
+IP_RE = rb"(?i)(?<![\w.-])(?:" + _OCTET_RE + rb"[.]){3}" + _OCTET_RE + rb"(?![\w.=-])"
 
 # Using some weird ranges to shorten the regex:
 # $-. is $%&'()*+,-. all of which are sub-delims $&'()*+, or unreserved .-
@@ -41,7 +41,7 @@ IP_RE = rb"(?i)(?<![\w.-])(?:" + _OCTET_RE + rb"[.]){3}" + _OCTET_RE + rb"(?![\w
 # #-/ is the same with # and /
 # #-& is #-/ but stopped before '
 URL_RE = (
-    rb"(?i)(?:ftp|https?)://"  # scheme
+    rb"(?i)(?:t?ftp|https?|wss?|udp|socks(?:\d[a-z]?)?)://"  # scheme
     rb"(?:[\w!$-.:;=~@]*@)?"  # userinfo
     rb"(?:(?!%5B)[%A-Z0-9.-]{4,253}|(?:\[|%5B)[%0-9A-F:]{3,117}(?:\]|%5D))"  # host
     rb"(?::[0-6]?[0-9]{0,4})?"  # port
@@ -122,19 +122,24 @@ def domain_is_false_positive(domain: bytes) -> bool:
     root_fpos = {
         b"abbrev",
         b"activate",
+        b"active",
         b"activesheet",
+        b"activesearch",
         b"activeworkbook",
         b"adodb",
         b"agent",
         b"algorithm",
         b"alias",
         b"analytic",
+        b"app",
         b"append",
         b"appendreplace",
         b"application",
         b"aquota",
         b"arena",
         b"arenastring",
+        b"arg",
+        b"argument",
         b"array",
         b"arrayprototype",
         b"ascii",
@@ -152,27 +157,36 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"bignum",
         b"bind",
         b"blake2",
+        b"border",
+        b"brushes",
         b"build",
         b"button",
         b"bytestream",
         b"callingworksheet",
+        b"cell",
+        b"cellcolor",
         b"cgroup",
         b"charconv",
         b"check",
+        b"child",
         b"city",
         b"clause",
         b"clean",
         b"client",
         b"clock",
+        b"cloud",
         b"code-of-conduct",
         b"color",
         b"column",
+        b"com",
         b"common",
         b"compile",
         b"component",
         b"condition",
         b"config",
         b"constructor",
+        b"contact",
+        b"container",
         b"context",
         b"contributing",
         b"conversion",
@@ -184,11 +198,14 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"crc32c",
         b"crypto",
         b"ctrl-alt-del",
+        b"cur",
         b"curve25519",
         b"cycleclock",
         b"data",
         b"date",
+        b"datetime",
         b"day",
+        b"dci",
         b"debbugger",
         b"decimal",
         b"default",
@@ -198,15 +215,19 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"delete",
         b"demangle",
         b"descripter",
+        b"dest",
+        b"destination",
         b"destructible",
         b"detail",
         b"di",
+        b"dimention",
         b"direction",
         b"div",
         b"division",
         b"document",
         b"double-to-string",
         b"downcall",
+        b"download",
         b"duration",
         b"ecdh",
         b"ecos",
@@ -217,6 +238,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"emergency",
         b"enduser",
         b"engine",
+        b"entry",
         b"error",
         b"escape",
         b"escaping",
@@ -226,11 +248,13 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"exit",
         b"expr",
         b"extention",
+        b"faas",
         b"fast-dtoa",
         b"feature",
         b"fence",
         b"field",
         b"file",
+        b"filter",
         b"fixed-dtoa",
         b"flag",
         b"float",
@@ -255,10 +279,18 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"grid",
         b"halt",
         b"hash",
+        b"header",
         b"heapsort",
         b"histogram",
         b"host",
+        b"http",
         b"httpd",
+        b"id",
+        "identification",
+        b"image",
+        b"img",
+        b"img1",
+        b"img2",
         b"index",
         b"info",
         b"infostream",
@@ -271,6 +303,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"install",
         b"installscript",
         b"instance",
+        b"instant",
         b"int",
         b"int16",
         b"int32",
@@ -280,9 +313,14 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"ipconf",
         b"it",
         b"item",
+        b"item1",
+        b"item2",
+        b"item3",
+        b"k8s",
         b"key",
         b"keydown",
         b"keyset",
+        b"label",
         b"layer",
         b"layerswitcher",
         b"legacy",
@@ -311,6 +349,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"metric",
         b"microsoft",
         b"mman",
+        b"model",
         b"mount",
         b"mutex",
         b"multi-user",
@@ -318,10 +357,12 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"mycell",
         b"nativedate",
         b"navigator",
+        b"net",
         b"netinfo",
         b"network",
         b"network-online",
         b"new",
+        b"node",
         b"notification",
         b"nss",
         b"nss-lookup",
@@ -329,14 +370,20 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"number",
         b"obj",
         b"object",
+        b"observation",
+        b"ocr",
+        b"off",
         b"offset",
         b"og",
         b"once",
         b"operation",
+        b"opt",
         b"option",
+        b"order",
         b"original",
         b"originalresult",
         b"org",
+        b"organization",
         b"os",
         b"oshlnk",
         b"ostringstream",
@@ -344,10 +391,13 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"output",
         b"package",
         b"packagejson",
+        b"par",
         b"parentoffset",
         b"parser",
         b"path",
         b"pattern",
+        b"pdf",
+        b"pen",
         b"performance",
         b"pickle",
         b"pipe",
@@ -355,16 +405,19 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"platform",
         b"port",
         b"poweroff",
+        b"preferences",
         b"printable",
         b"process",
         b"profile",
         b"program",
         b"progress",
+        b"prop",
         b"property",
         b"proposal",
         b"proto",
         b"prtime",
         b"prtracer",
+        b"question",
         b"quicksort",
         b"rand",
         b"randen",
@@ -379,6 +432,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"remote",
         b"remote-fs",
         b"remote-fs-pre",
+        b"rep",
         b"repository",
         b"rescue",
         b"response",
@@ -391,14 +445,17 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"rvalue",
         b"second",
         b"security",
+        b"select",
         b"selection",
         b"sequence",
+        b"serv",
         b"service",
         b"set",
         b"setting",
         b"sha1",
         b"sha256",
         b"sha512",
+        b"sheet",
         b"sheet1",
         b"sheet2",
         b"sheet3",
@@ -409,6 +466,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"sheet8",
         b"sheet9",
         b"shift",
+        b"shortcut",
         b"shutdown",
         b"signal",
         b"signalhandler",
@@ -452,18 +510,26 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"target",
         b"task",
         b"technique",
+        b"telemetry",
+        b"temp",
+        b"temporary",
         b"test",
         b"testdomain",
         b"thread",
         b"time",
-        b"timer",
         b"time-sync",
+        b"timer",
+        b"timespan",
         b"timezone",
+        b"title",
+        b"titlebar",
         b"token",
         b"tomcat",
+        b"total",
         b"tracing",
         b"track",
         b"trie",
+        b"try",
         b"tween",
         b"ui",
         b"uint16",
@@ -481,6 +547,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"util",
         b"uuid",
         b"value",
+        b"vba",
         b"vcl",
         b"vector",
         b"verinfo",
@@ -498,6 +565,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"wrapping",
         b"wscript",
         b"wshshell",
+        b"xfa",
         b"yes",
         b"zlib",
         b"zone",
@@ -1014,7 +1082,10 @@ def find_domains(data: bytes) -> list[Node]:
             obfuscation = "split"
         # Check if the preceeding character where this domain was found in the data is a "%"
         # Some of the URL encoding might be stuck to the domain that was found via regex.
-        elif preceeding_character == "%" and domain.lower().startswith((b"2f", b"40")):
+        elif (
+            re.match(rb"(?ir)(?:[%*]\s?3A|:)\s?[%*]\s?2F\s?[%*]\s?2F", data, endpos=start + 2)
+            or data[start - 1 : start + 2] == b"%40"
+        ):
             # If it is, we need to remove the trailing characters that follow as that's not part of the actual domain.
             domain = domain[2:]
             start = start + 2
@@ -1038,23 +1109,26 @@ def find_ips(data: bytes) -> list[Node]:
     """Find ip addresses in data"""
     out = []
     for match in re.finditer(IP_RE, data):
-        ip = match.group()
-        if not is_ip(ip):
+        try:
+            ip = parse_ip(match.group())
+        except ValueError:
+            continue  # Not an ip address
+        if ip.value == b"0.0.0.0":
             continue
-        if all(byte in b"0x." for byte in ip):
-            continue  # 0.0.0.0
-        if ip.endswith((b".0", b".255")):
+        if ip.value.endswith((b".0", b".255")):
             continue  # Class C network identifier or broadcast address
-        start, end = match.span()
-        prefix = data[start - 1 :: -1]
+        if ip.value != b"127.0.0.1" and len(ip.value.split(b".")[1]) == 1:
+            continue  # More likely to be a version number than an ip address
+        ip.shift(match.start())
+        prefix = data[ip.start - 1 :: -1]
         if re.match(rb"\s*>t(?::\w+)?<", prefix):
             continue  # xml section numbering
         if re.match(rb"(?i)\s+(?:noit|[.])ces", prefix):
             continue  # section number
-        offset = data.rfind(b"ersion", max(start - 10, 0), start)
-        if offset >= 0 and re.match(rb'[\x00=\s"]+$', data[offset + 6 : start]):
+        offset = data.rfind(b"ersion", max(ip.start - 10, 0), ip.start)
+        if offset >= 0 and re.match(rb'[\x00=\s"]+$', data[offset + 6 : ip.start]):
             continue  # version number, not an ip address
-        out.append(parse_ip(match.group()).shift(match.start()))
+        out.append(ip)
     return out
 
 
