@@ -98,6 +98,7 @@ def test_parse_ip():
         b"sec. 1.1.1.4",
         b"1.1.8.35-g8f5559c",
         b'version="1.2.0.58"',
+        b'@("2.5.29.37={text}1.3.6.1.5.5.7.3.1")',
     ],
 )
 def test_find_ips_false_positives(data):
@@ -214,6 +215,12 @@ def test_DOMAIN_RE_context(data, domain):
         b"component.name",
         b"mman.cc",
         b"utlook.com",
+        b"download.show",
+        b"question.name",
+        b"order.do",
+        b"label.name",
+        b"COM.INFO",
+        b"container.image.name",
     ],
 )
 def test_domain_is_false_positive(domain):
@@ -241,6 +248,9 @@ def test_domain_is_false_positive_real_domain(domain):
         (b"mailto:example.com@cyber.gc.ca", [Node("network.domain", b"cyber.gc.ca", "", 19, 30)]),
         (b"https://e\r\n\txample.com/path", [Node("network.domain", b"example.com", "split", 8, 22)]),
         (b"http://e\r\n\txample.com/path", [Node("network.domain", b"example.com", "split", 7, 21)]),
+        (b"&lt;a href=&quot;krakev.cc&quot;&gt;", [Node("network.domain", b"krakev.cc", "", 17, 26)]),
+        (b"https % 3A % 2F % 2Fdoi.org % 2F ", [Node("network.domain", b"doi.org", "", 20, 27)]),
+        (b"https:*2F*2Fexample.org*2f", [Node("network.domain", b"example.org", "", 12, 23)]),
     ],
 )
 def test_find_domains(data, domains):
@@ -326,6 +336,21 @@ def test_email_re():
         b"http://[::1%5D/path",  # Even handles the rest of the url just fine.
         # Large URLs
         b"http://youtube.com" + (b"%20" * 2000) + b"@google.com",
+        # UDP
+        b"udp://tracker.opentrackr.org:1337/announce",
+        # Curl socks examples https://ec.haxx.se/usingcurl/proxies/socks.html
+        b"socks4://proxy.example.com",
+        b"socks4a://proxy.example.com",
+        b"socks5://proxy.example.com",
+        b"socks5h://proxy.example.com",
+        # Socks without version
+        b"socks://proxy.example.com",
+        # WebSocket
+        b"ws://www.example.com",
+        b"wss://www.example.com/",
+        # FTP and TFTP
+        b"ftp://www.example.com",
+        b"tftp://example.com",
     ],
 )
 def test_URL_RE_matches(url):
